@@ -113,7 +113,7 @@ get_chemical_summary <- function(tox_list, ACC = NULL, filtered_ep = "All",
   }
   
   chemical_summary <- chemical_summary  %>%
-    left_join(select(chem_site, site=SiteID, `Short Name`),
+    left_join(distinct(select(chem_site, site=SiteID, `Short Name`)),
               by="site") %>%
     left_join(select(chem_info, CAS, Class), by="CAS") %>%
     rename(Bio_category = groupCol,
@@ -209,15 +209,16 @@ orderEP <- function(graphData){
 #' flagsShort value (used in the remove_flags function) are as follows:
 #' \tabular{ll}{
 #' \strong{Flag} \tab \strong{flagsShort}\cr
-#' Borderline active* \tab Borderline \cr
-#' Only highest conc above baseline, active* \tab OnlyHighest \cr
+#' Borderline active* \tab Borderline* \cr
+#' Only highest conc above baseline, active* \tab OnlyHighest* \cr
 #' Only one conc above baseline, active \tab OneAbove \cr
 #' Noisy data \tab Noisy \cr
 #' Hit-call potentially confounded by overfitting \tab HitCall \cr
-#' Gain AC50 < lowest conc & loss AC50 < mean conc* \tab GainAC50 \cr
-#' Biochemical assay with < 50\% efficacy \tab Biochemical* \cr
+#' Gain AC50 < lowest conc & loss AC50 < mean conc* \tab GainAC50* \cr
+#' Biochemical assay with < 50\% efficacy* \tab Biochemical* \cr
 #' Less than 50\% efficacy \tab LessThan50 \cr
-#' AC50 less than lowest concentration tested \tab ACCLessThan \cr
+#' AC50 less than lowest concentration tested* \tab ACCLessThan* \cr
+#' GNLSmodel \tab GNLSmodel \cr
 #' }
 #' Asterisks indicate flags removed in the function as default.
 #' 
@@ -225,7 +226,7 @@ orderEP <- function(graphData){
 #' @param ACC data frame with columns: casn, chnm, endPoint, and ACC_value
 #' @param flagsShort vector of flags to to trigger REMOVAL of chemical:endPoint 
 #' combination. Possible values are "Borderline", "OnlyHighest", "OneAbove",
-#' "Noisy", "HitCall", "GainAC50", "Biochemical","LessThan50","ACCLessThan".
+#' "Noisy", "HitCall", "GainAC50", "Biochemical","LessThan50","ACCLessThan","GNLSmodel".
 #' @export
 #' @examples 
 #' CAS <- c("121-00-6","136-85-6","80-05-7","84-65-1","5436-43-1","126-73-8")
@@ -234,9 +235,10 @@ orderEP <- function(graphData){
 #' ACC <- remove_flags(ACC)
 #' nrow(ACC)
 remove_flags <- function(ACC, flagsShort = c("Borderline",
-                                                 "OnlyHighest",
-                                                 "GainAC50",
-                                                 "Biochemical")){
+                                             "OnlyHighest",
+                                             "GainAC50",
+                                             "Biochemical", 
+                                             "ACCLessThan")){
   
   match.arg(flagsShort, 
             c("Borderline",
@@ -247,7 +249,8 @@ remove_flags <- function(ACC, flagsShort = c("Borderline",
               "GainAC50",
               "Biochemical",
               "LessThan50",
-              "ACCLessThan"),
+              "ACCLessThan",
+              "GNLSmodel"),
             several.ok = TRUE)
   
   flags <- ".dplyr"
@@ -261,7 +264,8 @@ remove_flags <- function(ACC, flagsShort = c("Borderline",
            GainAC50 = grepl("Gain AC50", flags),
            HitCall = grepl("potentially confounded by overfitting", flags),
            LessThan50 = grepl("Less than 50% efficacy", flags),
-           ACCLessThan = grepl("AC50 less than lowest concentration tested", flags)) %>%
+           ACCLessThan = grepl("AC50 less than lowest concentration tested", flags),
+           GNLSmodel = grepl("Cell viability assay fit with gnls winning model", flags)) %>%
     select(-flags)
   
   ACC <- ACC[rowSums(flag_hits[flagsShort]) == 0,]
@@ -278,7 +282,7 @@ remove_flags <- function(ACC, flagsShort = c("Borderline",
   #   "Only one conc above baseline, active",
   #   "AC50 less than lowest concentration tested",
   #   "Less than 50% efficacy",
-  #   "Noisy data")
+  #   "Noisy data","Cell viability assay fit with gnls winning model")
   
 }
 
